@@ -12,7 +12,7 @@ class User(UserBaseModal):
     email = EmailField(required=True)
     password = PasswordField(min=8, max=16, required=True)
     
-    dob = DateField(default='no date')
+    dob = DateField()
     bio = TextField()
     
     
