@@ -1,6 +1,6 @@
 
 from tesla.auth.decorators import login_required
-from tesla.auth.views import login as user_login
+from tesla.auth.views import login as user_login, authenticate
 from tesla.functions import url
 from tesla.response import HttpResponse, Redirect, Render, JsonResponse
 from tesla.pyhtml import CT
@@ -38,15 +38,13 @@ def collection_obj(request):
     obj = model_db.model().get(id=lookup)
     if 'json' in request.query:
         return JsonResponse(request, obj.json())
-    # print(model_db.model.property_cls())
-        
+     
     form = AdminForm(obj)
     form.model = model_db.model
     form.fields = '__all__'
     if request.method == 'POST':
         data = request.post.data
         del data['csrfmiddleware']
-        # col = model_db.model().get(id=lookup)
         obj.update(**data)
         obj.save()
     context = {}
@@ -112,10 +110,8 @@ def login(request):
     if request.method == 'POST':
         u = request.post.get('username')
         p = request.post.get('password')
-        # print(u, p)
-        user = User.get(username=u, password=p)
-        # print(user)
-        if isinstance(user, User):
+        user = User.get(username=u)
+        if authenticate(user, p):
             user_login(request , user)
             return Redirect(request, 'admin:index')
     return Render(request, 'admin/login.html')
