@@ -100,11 +100,9 @@ class DBCache:
         return o.values() if o else []
 
     def remove(self, collection, key):
-        for c in self.db[collection]:
-            if c.get('id') == id:
-                self.db[collection].remove(c)
-                break
-
+        del self.db[collection][key]
+        
+        
 
 local_db = DBCache({})
 
@@ -254,6 +252,13 @@ class JsonDB:
                 '/')[0], model.get('id'), model)
             return None
 
+    def delete(self, table_name):
+        os.remove(self.path + self.collection + table_name + '.json')
+        local_db.remove(self.collection[:-1], table_name)
+        return None
+        
+        
+        
     def all(self, models=False):
         # print(local_db)
 
