@@ -196,12 +196,16 @@ class Model:
         return db.filter(kwargs)   
 
     @classmethod
-    def all(cls, **kwargs):
+    def all(cls, model=True):
         # print(dir(cls))
         db = JsonDB(collection = cls.__name__ + "/") 
+        if not model:
+            return list(db.all())
         l = []
         for m in db.all():
-            c = cls(**m)
+            c = cls()
+            for k, v in m.items():
+                setattr(c, k, v) 
             c.assign_foreign()
             l.append(c)
         return  l
@@ -259,6 +263,10 @@ class Model:
     def json(self):
         return self.__dict__
     
+    def delete(self):
+        self.db.delete(self.id)
+        return None
+    
     def assign_foreign(self):
         # print(self)
         js = deepcopy(list(self.json().items()))
